@@ -10,7 +10,7 @@ use strict;
 use vars qw($VERSION);
 use IO::File;
 
-$VERSION = "0.17"; # $Id: TFTP.pm 12 2007-07-18 11:32:42Z gbarr $
+$VERSION = "0.19";
 
 sub RRQ	  () { 01 } # read request
 sub WRQ	  () { 02 } # write request
@@ -129,8 +129,11 @@ sub get {
 
     my $file = $local;
     unless(ref($local)) {
-	unlink($file);
 	$local = IO::File->new($file,O_WRONLY|O_TRUNC|O_CREAT);
+        unless ($local) {
+                $self->{'error'} = "Can not open $file: $!";
+                return undef;
+        }
     }
 
     binmode $local if $self->{'Mode'} eq 'octet';
@@ -222,6 +225,11 @@ sub new {
     $opts->{'ascii'} = lc($opts->{'Mode'}) eq "netascii";
 
     my $host = $opts->{'Host'};
+    do {
+            $tftp->{'error'} = "No hostname given";
+            return undef;
+    } unless defined($host);
+
     ## jjmb - had to make an adjustment here the logic used originally does not work well
     ##        with IPv6.
     my $port = undef;
